[![Stories in Ready](https://badge.waffle.io/powellc/planadversity.png?label=ready&title=Ready)](https://waffle.io/powellc/planadversity)

[![Build Status](https://travis-ci.org/powellc/planadversity.svg?branch=master)](https://travis-ci.org/powellc/planadversity)

Hack Labs
=========

Our mission at Hack Labs is to create a program where young people are provided
with inspiration and guidance to create and make things using software and
hardware.

Technology
----------

We'd love to be able to provide kids from the middle school level on up with a
chance to play with the following technologies, amongst pretty much anything
else:

  * Arduino
  * Raspberry Pi
  * Linux as a desktop
  * Python
  * Ruby
  * PHP
  * C/C++
  * Android/Java development

